价格面板 - Bootstrap后台管理系统模版Ace下载
Description: 站长素材提供Bootstrap模版,Bootstrap教程,Bootstrap中文翻译等相关Bootstrap插件下载
Keywords: Bootstrap模版,Bootstrap模版下载,Bootstrap教程,Bootstrap中文

# Pricing Tables Large & Small

##### Basic Package

- 10 GB Disk Space
- 200 GB Bandwidth
- 100 Email Accounts
- 10 MySQL Databases
- $10 Ad Credit
- Free Domain

$5 /month
Buy

##### Starter Package

- 50 GB Disk Space
- 1 TB Bandwidth
- 1000 Email Accounts
- 100 MySQL Databases
- $25 Ad Credit
- Free Domain

$10 /month
Buy

##### Business Package

- 200 GB Disk Space
- Unlimited Bandwidth
- 1000 Email Accounts
- 200 MySQL Databases
- $25 Ad Credit
- Free Domain

$15 /month
Buy

##### Ultimate Package

- Unlimited Space
- Unlimited Bandwidth
- Unlimited Email Accounts
- Unlimited MySQL Databases
- $50 Ad Credit
- 2 Free Domains

$25 /month
Buy

### Small Style

##### Package Name

- Disk Space
- Bandwidth
- Email Accounts
- MySQL Databases
- Ad Credit
- Free Domain

##### Basic

- 10 GB
- 200 GB
- 100
- 10
- $10

$5 /month
Buy

##### Starter

- 50 GB
- 1 TB
- 1000
- 100
- $25
- 1

$10 /month
Buy

##### Business

- 200 GB
- Unlimited
- 1000
- 200
- $25
- 1

$15 /month
Buy

##### Unlimited

- Unlimited
- Unlimited
- Unlimited
- Unlimited
- $50
- 2

$25 /month
Buy

##### Extreme

- Unlimited
- Unlimited
- Unlimited
- Unlimited
- $100
- 3

$30 /month
Buy
Choose Skin
Fixed Navbar
Fixed Sidebar
Fixed Breadcrumbs
Right To Left (rtl)
Inside .container